ArgVmProviderFactory2<T extends ViewModel, A, B> class

Constructors

ArgVmProviderFactory2(T creator(StoreSpace space, A, B), {dynamic disposer(T instance)?, List<Object?> equatableProps(A arg1, B arg2)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(A arg1, B arg2) ViewModelProviderBase<T>
createViewModel(StoreSpace space, A arg1, B arg2) → T
disposeViewModel(T instance) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited