ArgVmProviderFactory5<T extends ViewModel, A, B, C, D, E> class
Constructors
-
ArgVmProviderFactory5(T creator(StoreSpace space, A, B, C, D, E), {dynamic disposer(T instance)?, List<
Object?> equatableProps(A arg1, B arg2, C arg3, D arg4, E arg5)?}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
A arg1, B arg2, C arg3, D arg4, E arg5) → ViewModelProviderBase< T> -
createViewModel(
StoreSpace space, A arg1, B arg2, C arg3, D arg4, E arg5) → T -
disposeViewModel(
T instance) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited