StoreOwner class abstract

Interface for objects that own a Store instance. Provides access to the store and ability to unmount it.

Implementers

Constructors

StoreOwner()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store Store
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unmountStore() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited