ScopeAware class abstract
An interface for objects that expose their own lifecycle scope.
Implement this interface to allow external listeners to observe the lifecycle of the object via the scope property. When the scope becomes invalid (for example, when the object is disposed), all listeners will be notified.
It is recommended to use DisposeStateNotifier to implement this interface, as it provides a convenient way to manage and notify disposal state.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → Listenable
-
A Listenable that notifies listeners when this object's scope becomes invalid,
typically when the object is disposed.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited