StoreSpace class
- Implemented types
- Available extensions
Constructors
- StoreSpace(Store _store, Listenable scope)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mounted → bool
-
Whether the store is currently mounted and active.
Returns true if the store is mounted and can handle provider operations.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → Listenable
-
A Listenable that notifies listeners when this object's scope becomes invalid,
typically when the object is disposed.
final
Methods
-
bind<
T> (ProviderBase< T> provider) → T - Binds a provider within the current space scope.
-
bindWith<
T> (ProviderBase< T> provider, Listenable scope) → T -
Binds a provider to a disposable widget or object.
The provider instance will be tracked and cleaned up when the disposeNotifier signals disposal.
This method is used to create scoped provider instances that are tied to widget lifecycle.
override
-
bindWithScoped<
T> (ProviderBase< T> provider, ScopeAware scopeAware) → T -
Available on Store, provided by the StoreExtension extension
-
exists<
T> (ProviderBase< T> provider) → bool -
Checks if a provider instance has already been created in the store.
override
-
find<
T> (ProviderBase< T> provider) → T? -
Finds an existing provider instance in the store.
Returns null if the provider instance hasn't been created yet.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
Gets or creates a provider instance.
If the instance doesn't exist, it will be created and cached.
This method is typically used for accessing global shared state.
override
-
temporary<
T> (ProviderBase< T> provider) → T -
Available on Store, provided by the StoreExtension extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited